﻿using System;
using System.ComponentModel;

using DevExpress.XtraEditors;
using DevExpress.XtraEditors.Controls;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.fromDateEdit.Validating   += fromDateEdit_Validating;
            this.fromDateEdit.InvalidValue += fromDateEdit_InvalidValue;
            this.fromDateEdit.Validated    += fromDateEdit_Validated;
            this.toDateEdit.Validating     += toDateEdit_Validating;
            this.toDateEdit.InvalidValue   += toDateEdit_InvalidValue;
            this.toDateEdit.Validated      += toDateEdit_Validated;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region FROM 날짜 에디터 값 검증시 처리하기 - fromDateEdit_Validating(sender, e)

        /// <summary>
        /// FROM 날짜 에디터 값 검증시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void fromDateEdit_Validating(object sender, CancelEventArgs e)
        {
            if(this.fromDateEdit.EditValue == null)
            {
                e.Cancel = false;
            }
            else
            {
                if(this.toDateEdit.EditValue == null)
                {
                    e.Cancel = false;
                }
                else
                {
                    if(this.fromDateEdit.DateTime > this.toDateEdit.DateTime)
                    {
                        this.fromDateEdit.ErrorText = "FROM 날짜가 TO 날짜보다 큽니다.";
                        
                        e.Cancel = true;
                    }
                }
            }
        }

        #endregion
        #region FROM 날짜 에디터 무효한 값 처리하기 - fromDateEdit_InvalidValue(sender, e)

        /// <summary>
        /// FROM 날짜 에디터 무효한 값 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void fromDateEdit_InvalidValue(object sender, InvalidValueExceptionEventArgs e)
        {
            e.ExceptionMode = ExceptionMode.NoAction;

           this.messageTextEdit.Text = this.fromDateEdit.ErrorText;
        }

        #endregion
        #region FROM 날짜 에디터 검증 완료시 처리하기 - fromDateEdit_Validated(object sender, EventArgs e)

        /// <summary>
        /// FROM 날짜 에디터 검증 완료시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void fromDateEdit_Validated(object sender, EventArgs e)
        {
            this.messageTextEdit.Text = string.Empty;
        }

        #endregion
        #region TO 날짜 에디터 값 검증시 처리하기 - toDateEdit_Validating(sender, e)

        /// <summary>
        /// TO 날짜 에디터 값 검증시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void toDateEdit_Validating(object sender, CancelEventArgs e)
        {
            if(this.toDateEdit.EditValue == null)
            {
                e.Cancel = false;
            }
            else
            {
                if(this.fromDateEdit.EditValue == null)
                {
                    e.Cancel = false;
                }
                else
                {
                    if(this.toDateEdit.DateTime < this.fromDateEdit.DateTime)
                    {
                        this.toDateEdit.ErrorText = "TO 날짜가 FROM 날짜보다 작습니다.";

                        e.Cancel = true;
                    }
                }
            }
        }

        #endregion
        #region TO 날짜 에디터 무효한 값 처리하기 - toDateEdit_InvalidValue(sender, e)

        /// <summary>
        /// TO 날짜 에디터 무효한 값 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void toDateEdit_InvalidValue(object sender, InvalidValueExceptionEventArgs e)
        {
            e.ExceptionMode = ExceptionMode.NoAction;

           this.messageTextEdit.Text = this.toDateEdit.ErrorText;
        }

        #endregion
        #region TO 날짜 에디터 검증 완료시 처리하기 - toDateEdit_Validated(object sender, EventArgs e)

        /// <summary>
        /// TO 날짜 에디터 검증 완료시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void toDateEdit_Validated(object sender, System.EventArgs e)
        {
            this.messageTextEdit.Text = string.Empty;
        }

        #endregion
    }
}